@@ -145,21 +145,28 @@ Matrix <- function (data = NA, nrow = 1, ncol = 1, byrow = FALSE,
     sparseDefault <- function(m) prod(dim(m)) > 2*sum(isN0(as(m, "matrix")))
 
     i.M <- is(data, "Matrix")
+    sM <- FALSE
     if(i.M) {
 	if(is(data, "diagonalMatrix")) return(data) # in all cases
+	sV <- FALSE
     } else if(inherits(data, "table")) # special treatment
 	class(data) <- "matrix" # "matrix" first for S4 dispatch
+    else if(is(data, "sparseVector")) {
+	data <- spV2M(data, nrow, ncol, byrow=byrow)
+	i.M <- sparse <- forceCheck <- sM <- sV <- TRUE
+    }
     if(is.null(sparse1 <- sparse) && (i.M || is(data, "matrix")))
 	sparse <- sparseDefault(data)
-    sM <- FALSE
     doDN <- TRUE
     if (i.M) {
-        if(!missing(nrow) || !missing(ncol)|| !missing(byrow))
-            warning("'nrow', 'ncol', etc, are disregarded when 'data' is \"Matrix\" already")
-	sM <- is(data,"sparseMatrix")
-	if(!forceCheck && ((sparse && sM) || (!sparse && !sM)))
-	    return(data)
-	## else : convert  dense <-> sparse -> at end
+	if (!sV) {
+	    if(!missing(nrow) || !missing(ncol)|| !missing(byrow))
+		warning("'nrow', 'ncol', etc, are disregarded when 'data' is \"Matrix\" already")
+	    sM <- is(data,"sparseMatrix")
+	    if(!forceCheck && ((sparse && sM) || (!sparse && !sM)))
+		return(data)
+	    ## else : convert  dense <-> sparse -> at end
+	}
     }
     else if (!is.matrix(data)) { ## cut & paste from "base::matrix" :
 	if (missing(nrow))
@@ -235,41 +242,6 @@ Matrix <- function (data = NA, nrow = 1, ncol = 1, byrow = FALSE,
 
 ## Methods for operations where one argument is numeric
 
-## Using as.matrix() and rbind()
-## in order to get dimnames from names {at least potentially}:
-
-setMethod("%*%", signature(x = "Matrix", y = "numeric"),
-	  function(x, y) callGeneric(x, as.matrix(y)))
-setMethod("%*%", signature(x = "numeric", y = "Matrix"),
-	  function(x, y) callGeneric(matrix(x, nrow = 1, byrow=TRUE), y))
-
-setMethod("%*%", signature(x = "Matrix", y = "matrix"),
-	  function(x, y) callGeneric(x, Matrix(y)))
-setMethod("%*%", signature(x = "matrix", y = "Matrix"),
-	  function(x, y) callGeneric(Matrix(x), y))
-
-
-setMethod("crossprod", signature(x = "Matrix", y = "numeric"),
-	  function(x, y = NULL) callGeneric(x, as.matrix(y)))
-setMethod("crossprod", signature(x = "numeric", y = "Matrix"),
-	  function(x, y = NULL)	 callGeneric(as.matrix(x), y))
-
-setMethod("crossprod", signature(x = "Matrix", y = "matrix"),
-	  function(x, y = NULL) callGeneric(x, Matrix(y)))
-setMethod("crossprod", signature(x = "matrix", y = "Matrix"),
-	  function(x, y = NULL) callGeneric(Matrix(x), y))
-
-## The as.matrix() promotion seems illogical to MM,
-## but is according to help(tcrossprod, package = "base") :
-setMethod("tcrossprod", signature(x = "Matrix", y = "numeric"),
-	  function(x, y = NULL) callGeneric(x, as.matrix(y)))
-setMethod("tcrossprod", signature(x = "numeric", y = "Matrix"),
-	  function(x, y = NULL)	 callGeneric(as.matrix(x), y))
-setMethod("tcrossprod", signature(x = "Matrix", y = "matrix"),
-	  function(x, y = NULL) callGeneric(x, Matrix(y)))
-setMethod("tcrossprod", signature(x = "matrix", y = "Matrix"),
-	  function(x, y = NULL) callGeneric(Matrix(x), y))
-
 ## maybe not 100% optimal, but elegant:
 setMethod("solve", signature(a = "Matrix", b = "missing"),
 	  function(a, b, ...) solve(a, Diagonal(nrow(a))))
@@ -290,28 +262,6 @@ setMethod("solve", signature(a = "Matrix", b = "ANY"),
 setMethod("solve", signature(a = "ANY", b = "Matrix"),
 	  function(a, b, ...) .bail.out.2("solve", class(a), class(b)))
 
-## bail-out methods in order to get better error messages
-	  .local.bail.out = function (x, y)
-          stop(gettextf('not-yet-implemented method for <%s> %%*%% <%s>',
-                        class(x), class(y)))
-
-setMethod("%*%", signature(x = "ANY", y = "Matrix"), .local.bail.out)
-setMethod("%*%", signature(x = "Matrix", y = "ANY"), .local.bail.out)
-
-## cheap fallbacks
-setMethod("crossprod", signature(x = "Matrix", y = "Matrix"),
-	  function(x, y = NULL) t(x) %*% y)
-setMethod("crossprod", signature(x = "Matrix", y = "ANY"),
-	  function(x, y = NULL) t(x) %*% y)
-setMethod("crossprod", signature(x = "ANY", y = "Matrix"),
-	  function(x, y = NULL) t(x) %*% y)
-setMethod("tcrossprod", signature(x = "Matrix", y = "Matrix"),
-	  function(x, y = NULL) x %*% t(y))
-setMethod("tcrossprod", signature(x = "Matrix", y = "ANY"),
-	  function(x, y = NULL) x %*% t(y))
-setMethod("tcrossprod", signature(x = "ANY", y = "Matrix"),
-	  function(x, y = NULL) x %*% t(y))
-
 ## There are special sparse methods; this is a "fall back":
 setMethod("kronecker", signature(X = "Matrix", Y = "ANY",
 				 FUN = "ANY", make.dimnames = "ANY"),
