@@ -33,31 +33,6 @@ setAs("BunchKaufman", "lMatrix",
 ##       show( <ddenseMatrix> ) is not okay, and we need our own:
 setMethod("show", "dtrMatrix", function(object) prMatrix(object))
 
-setMethod("%*%", signature(x = "dtrMatrix", y = "ddenseMatrix"),
-	  function(x, y) .Call(dtrMatrix_matrix_mm, x, y, FALSE),
-          valueClass = "dgeMatrix")
-
-setMethod("%*%", signature(x = "dtrMatrix", y = "matrix"),
-	  function(x, y) .Call(dtrMatrix_matrix_mm, x, y, FALSE),
-          valueClass = "dgeMatrix")
-
-setMethod("%*%", signature(x = "ddenseMatrix", y = "dtrMatrix"),
-	  function(x, y) .Call(dtrMatrix_matrix_mm, y, x, TRUE),
-          valueClass = "dgeMatrix")
-
-setMethod("%*%", signature(x = "matrix", y = "dtrMatrix"),
-	  function(x, y) .Call(dtrMatrix_matrix_mm, y, x, TRUE),
-          valueClass = "dgeMatrix")
-
-## no longer needed
-## setMethod("%*%", signature(x = "dtrMatrix", y = "dtrMatrix"),
-## 	  function(x, y) callGeneric(x = x, y = as(y, "dgeMatrix")),
-##           valueClass = "dgeMatrix")
-
-setMethod("crossprod", signature(x = "dtrMatrix", y = "missing"),
-	  function(x, y = NULL) callGeneric(x = as(x, "dgeMatrix")),
-	  valueClass = "dpoMatrix")
-
 setMethod("determinant", signature(x = "dtrMatrix", logarithm = "missing"),
 	  function(x, logarithm, ...) callGeneric(x, TRUE))
 
