@@ -442,7 +442,10 @@ int CHOLMOD(resymbol_noperm)
 	/* ------------------------------------------------------------------ */
 
 	/* flag the diagonal entry */
-	mark = CHOLMOD(clear_flag) (Common) ;
+	/* mark = CHOLMOD(clear_flag) (Common) ; */
+	CHOLMOD_CLEAR_FLAG (Common) ;
+	mark = Common->mark ;
+
 	Flag [k] = mark ;
 	PRINT1 (("	row: "ID" (diagonal)\n", k)) ;
 
@@ -596,7 +599,9 @@ int CHOLMOD(resymbol_noperm)
     /* clear workspace */
     /* ---------------------------------------------------------------------- */
 
-    CHOLMOD(clear_flag) (Common) ;
+    /* CHOLMOD(clear_flag) (Common) ; */
+    CHOLMOD_CLEAR_FLAG (Common) ;
+
     DEBUG (CHOLMOD(dump_factor) (L, "ReSymbol final L (i, x):", Common)) ;
     ASSERT (CHOLMOD(dump_work) (TRUE, TRUE, 0, Common)) ;
     return (TRUE) ;
