@@ -69,7 +69,7 @@ SEXP dgCMatrix_set_Dim(SEXP x, int nrow);
 /* int csc_unsorted_columns(int ncol, const int p[], const int i[]); */
 /* void csc_sort_columns(int ncol, const int p[], int i[], double x[]); */
 /* SEXP csc_check_column_sorting(SEXP A); */
-SEXP Matrix_make_named(int TYP, char **names);
+SEXP Matrix_make_named(int TYP, const char **names);
 SEXP check_scalar_string(SEXP sP, char *vals, char *nm);
 Rboolean equal_string_vectors(SEXP s1, SEXP s2);
 
@@ -270,6 +270,8 @@ Matrix_check_class(const char *class, char **valid)
     }
 }
 
+int Matrix_check_class_etc(SEXP x, char **valid);
+int Matrix_check_class_and_super(SEXP x, char **valid, SEXP rho);
 
 #ifdef __cplusplus
 }
