@@ -26,7 +26,7 @@ SEXP dppMatrix_chol(SEXP x)
     SET_SLOT(val, Matrix_uploSym, duplicate(uploP));
     SET_SLOT(val, Matrix_diagSym, mkString("N"));
     SET_SLOT(val, Matrix_DimSym, duplicate(dimP));
-    SET_SLOT(val, Matrix_xSym, duplicate(GET_SLOT(x, Matrix_xSym)));
+    slot_dup(val, x, Matrix_xSym);
     F77_CALL(dpptrf)(uplo, dims, REAL(GET_SLOT(val, Matrix_xSym)), &info);
     if (info) {
 	if(info > 0) /* e.g. x singular */
@@ -59,9 +59,9 @@ SEXP dppMatrix_solve(SEXP x)
     SEXP val = PROTECT(NEW_OBJECT(MAKE_CLASS("dppMatrix")));
     int *dims = INTEGER(GET_SLOT(x, Matrix_DimSym)), info;
 
-    SET_SLOT(val, Matrix_uploSym, duplicate(GET_SLOT(Chol, Matrix_uploSym)));
-    SET_SLOT(val, Matrix_xSym, duplicate(GET_SLOT(Chol, Matrix_xSym)));
-    SET_SLOT(val, Matrix_DimSym, duplicate(GET_SLOT(Chol, Matrix_DimSym)));
+    slot_dup(val, Chol, Matrix_uploSym);
+    slot_dup(val, Chol, Matrix_xSym);
+    slot_dup(val, Chol, Matrix_DimSym);
     F77_CALL(dpptri)(uplo_P(val), dims,
 		     REAL(GET_SLOT(val, Matrix_xSym)), &info);
     UNPROTECT(1);
